/**
 * TheCitadelofRicks
 *
 * Copyright 2019  <seil0@mosad.xyz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

package org.mosad.thecitadelofricks.hsoparser

import org.jsoup.Jsoup
import org.junit.jupiter.api.Assertions
import org.junit.jupiter.api.Test
import java.io.File

internal class MensaParserTest {
    private val mensaMenuURL = "https://www.swfr.de/de/essen-trinken/speiseplaene/mensa-offenburg/"

    @Test
    fun parseMensaMenuNormalWeek() {
        val htmlFile = File(MensaParserTest::class.java.getResource("/html/Mensa_normal-week.html").path)
        val htmlDoc = Jsoup.parse(htmlFile,"UTF-8", "https://www.swfr.de/")
        val mensaWeek = MensaParser().parseMensaMenu(htmlDoc)

        // maybe we can find another way for the comparison
        Assertions.assertEquals(
            "MensaWeek(days=[Meals(meals=[Meal(day=Montag 03.07., heading=Essen 1, parts=[Gemüseauflauf , Frischkäse-Paprikasauce , Blattsalat <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9, enthält Allergene: Ei,ML,Lak</span>], additives=Kennzeichnungen/Zusatzstoffe: 9 enthält Allergene: Ei,ML,Lak), Meal(day=Montag 03.07., heading=Essen 2, parts=[Schweinesteak , Pfeffer-Rahmsauce , Country Potatoes , Blattsalat <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 1,5</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 1,5, enthält Allergene: Gl,GlW,GlG,ML,Lak</span>], additives=Kennzeichnungen/Zusatzstoffe: 1,5 enthält Allergene: Gl,GlW,GlG,ML,Lak), Meal(day=Montag 03.07., heading=Buffet, parts=[Grill und Salatbar , Asiatisches aus dem Wok , Fleisch- und Fischspezialitäten , Pasta-, Reis und Kartoffelvariationen , Gemüse], additives=)]), Meals(meals=[Meal(day=Dienstag 04.07., heading=Essen 1, parts=[Riesenrösti , Rahmchampignons , Blattsalat <span class=\"zusatzsstoffe show-with-allergenes\">enthält Allergene: Gl,GlW,GlG,ML,Lak</span>], additives=enthält Allergene: Gl,GlW,GlG,ML,Lak), Meal(day=Dienstag 04.07., heading=Essen 2, parts=[Spaghetti , Sauce Bolognese , Geriebener Hartkäse , Blattsalat <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 15</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 15, enthält Allergene: Ei,Se,Gl,GlW,ML</span>], additives=Kennzeichnungen/Zusatzstoffe: 15 enthält Allergene: Ei,Se,Gl,GlW,ML), Meal(day=Dienstag 04.07., heading=Buffet, parts=[Grill und Salatbar , Asiatisches aus dem Wok , Fleisch- und Fischspezialitäten , Pasta-, Reis und Kartoffelvariationen , Gemüse], additives=)]), Meals(meals=[Meal(day=Mittwoch 05.07., heading=Essen 1, parts=[Frühlingsrollen , Feuriger Chilidip , Patnareis , Wokgemüsepfanne <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9, enthält Allergene: Ei,So,Sn,Se,Sf,Gl,GlW,ML,Lak</span>], additives=Kennzeichnungen/Zusatzstoffe: 9 enthält Allergene: Ei,So,Sn,Se,Sf,Gl,GlW,ML,Lak), Meal(day=Mittwoch 05.07., heading=Essen 2, parts=[Bratwurstschnecke , Bratenjus , Kartoffelbrei , Karottengemüse <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 1,8</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 1,8, enthält Allergene: Sn,Se,Gl,GlW,GlG,ML,Lak</span>], additives=Kennzeichnungen/Zusatzstoffe: 1,8 enthält Allergene: Sn,Se,Gl,GlW,GlG,ML,Lak), Meal(day=Mittwoch 05.07., heading=Buffet, parts=[Grill und Salatbar , Asiatisches aus dem Wok , Fleisch- und Fischspezialitäten , Pasta-, Reis und Kartoffelvariationen , Gemüse], additives=)]), Meals(meals=[Meal(day=Donnerstag 06.07., heading=Essen 1, parts=[Farfalle tricolore , Gorgonzola-Spinatsauce , Endiviensalat <span class=\"zusatzsstoffe show-with-allergenes\">enthält Allergene: Gl,GlW,ML</span>], additives=enthält Allergene: Gl,GlW,ML), Meal(day=Donnerstag 06.07., heading=Essen 2, parts=[Paniertes Seelachsfilet MSC , Remouladensauce , Salzkartoffeln , Brokkoligemüse <span class=\"zusatzsstoffe hide-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9,MSC</span> <span class=\"zusatzsstoffe show-with-allergenes\">Kennzeichnungen/Zusatzstoffe: 9,MSC, enthält Allergene: Ei,Sn,Fi,Gl,GlW,ML,Lak</span>], additives=Kennzeichnungen/Zusatzstoffe: 9,MSC enthält Allergene: Ei,Sn,Fi,Gl,GlW,ML,Lak), Meal(day=Donnerstag 06.07., heading=Buffet, parts=[Grill und Salatbar , Asiatisches aus dem Wok , Fleisch- und Fischspezialitäten , Pasta-, Reis und Kartoffelvariationen , Gemüse], additives=)]), Meals(meals=[Meal(day=Freitag 07.07., heading=Essen 1, parts=[Italienischer Nudelauflauf mit Gemüse , Tomatenragout , Blattsalat <span class=\"zusatzsstoffe show-with-allergenes\">enthält Allergene: Gl,GlW,ML,Lak</span>], additives=enthält Allergene: Gl,GlW,ML,Lak), Meal(day=Freitag 07.07., heading=Essen 2, parts=[Hähnchen-Saté-Spieß , Erdnusssauce , Langkornreis , Karotten-Erbsengemüse <span class=\"zusatzsstoffe show-with-allergenes\">enthält Allergene: Er,So,Kr,Fi,We,Gl,GlW,ML,Lak</span>], additives=enthält Allergene: Er,So,Kr,Fi,We,Gl,GlW,ML,Lak), Meal(day=Freitag 07.07., heading=Buffet, parts=[Grill und Salatbar , Asiatisches aus dem Wok , Fleisch- und Fischspezialitäten , Pasta-, Reis und Kartoffelvariationen , Gemüse], additives=)]), Meals(meals=[]), Meals(meals=[])])",
            mensaWeek.toString()
        )

    }

    @Test
    fun parseMensaMenuEmptyWeek() {
        val htmlFile = File(MensaParserTest::class.java.getResource("/html/Mensa_empty-week.html").path)
        val htmlDoc = Jsoup.parse(htmlFile,"UTF-8", "https://www.swfr.de/")
        val mensaWeek = MensaParser().parseMensaMenu(htmlDoc)

        Assertions.assertEquals(
            "MensaWeek(days=[Meals(meals=[]), Meals(meals=[]), Meals(meals=[]), Meals(meals=[]), Meals(meals=[]), Meals(meals=[]), Meals(meals=[])])",
            mensaWeek.toString()
        )
    }

    // TODO add test for special days ie. public holiday

    @Test
    fun getMenuLinkNextWeek() {
        val urlNextWeek = MensaParser().getMenuLinkNextWeek(mensaMenuURL) // this need a connection to the swfr server
        Assertions.assertNotNull(urlNextWeek)
    }
}